@@ -81,6 +81,7 @@ class Client():
             lines: Union[str, list, None] = None,
             passlist: bool = False,
             board_type: Literal[BoardArrivalType.ARR, BoardArrivalType.ARR_EQUIVS, BoardArrivalType.ARR_MAST, BoardArrivalType.ARR_STATION] = BoardArrivalType.ARR,
+            retrieve_stops: bool = True
         ) -> BoardArrival:
         """Method returns a board with arriving transport. 
 
@@ -98,6 +99,7 @@ class Client():
             * lines (`Union[str, list]`, **optional**): Only journeys running the given line are part of the result. To filter multiple lines, provide a list or separate the codes by comma or provide a list. If the line should not be part of the be trip, negate it by putting ! in front of it. Defaults to `None`.
             * passlist (`bool`, **optional**): Include a list of all passed waystops. Defaults to `False`.
             * board_type (`Union[BoardArrivalType.ARR, BoardArrivalType.ARR_EQUIVS, BoardArrivalType.ARR_MAST, BoardArrivalType.ARR_STATION]`, optional): Set the station arrival board type to be used. Defaults to `BoardArrivalType.ARR`.
+            * retrieve_stops (`bool`, **optional**): Whether the stops should be retrieved as a `Stop` objects. Using `False` will drastically increase processing speed and decrease number of requests made (good for low access_key rate limit). Defaults to `True`.
 
         ### Returns:
             * BoardArrival: Instance of `BoardArrival` object.
@@ -123,7 +125,7 @@ class Client():
 
         find_exception(board_raw)
 
-        return BoardArrival(board_raw, self)
+        return BoardArrival(board_raw, self, retrieve_stops=retrieve_stops)
 
     def board_departure(self,
             id: Union[str, None] = None,
@@ -137,6 +139,7 @@ class Client():
             lines: Union[str, list, None] = None,
             passlist: bool = False,
             board_type: Literal[BoardDepartureType.DEP, BoardDepartureType.DEP_EQUIVS, BoardDepartureType.DEP_MAST, BoardDepartureType.DEP_STATION] = BoardDepartureType.DEP,
+            retrieve_stops: bool = True
         ) -> BoardDeparture:
         """Method returns a board with departing transport. 
 
@@ -154,6 +157,7 @@ class Client():
             * lines (`Union[str, list]`, **optional**): Only journeys running the given line are part of the result. To filter multiple lines, provide a list or separate the codes by comma or provide a list. If the line should not be part of the be trip, negate it by putting ! in front of it. Defaults to `None`.
             * passlist (`bool`, **optional**): Include a list of all passed waystops. Defaults to `False`.
             * board_type (`Union[BoardDepartureType.DEP, BoardDepartureType.DEP_EQUIVS, BoardDepartureType.DEP_MAST, BoardDepartureType.DEP_STATION]`, optional): Set the station departure board type to be used. Defaults to `BoardDepartureType.DEP`.
+            * retrieve_stops (`bool`, **optional**): Whether the stops should be retrieved as a `Stop` objects. Using `False` will drastically increase processing speed and decrease number of requests made (good for low access_key rate limit). Defaults to `True`.
 
         ### Returns:
             * BoardDeparture: Instance of `BoardDeparture` object.
@@ -179,7 +183,7 @@ class Client():
 
         find_exception(board_raw)
 
-        return BoardDeparture(board_raw, self)
+        return BoardDeparture(board_raw, self, retrieve_stops=retrieve_stops)
 
     def him_search(self,
             date_begin: Union[str, datetime, None] = None,
@@ -297,8 +301,9 @@ class Client():
 
         find_exception(messages_raw)
 
-        for message in messages_raw["Message"]:
-            messages.append(Message(message))
+        if "Message" in messages_raw:
+            for message in messages_raw["Message"]:
+                messages.append(Message(message))
 
         return messages
 
@@ -398,11 +403,12 @@ class Client():
 
         find_exception(stops_raw)
 
-        for stop in stops_raw["stopLocationOrCoordLocation"]:
-            if "StopLocation" in stop:
-                stops.append(Stop(stop["StopLocation"]))
-            elif "CoordLocation" in stop:
-                stops.append(Stop(stop["CoordLocation"]))
+        if "stopLocationOrCoordLocation" in stops_raw:
+            for stop in stops_raw["stopLocationOrCoordLocation"]:
+                if "StopLocation" in stop:
+                    stops.append(Stop(stop["StopLocation"]))
+                elif "CoordLocation" in stop:
+                    stops.append(Stop(stop["CoordLocation"]))
 
         return stops
 
@@ -500,11 +506,12 @@ class Client():
 
         find_exception(stops_raw)
 
-        for stop in stops_raw["stopLocationOrCoordLocation"]:
-            if "StopLocation" in stop:
-                stops.append(Stop(stop["StopLocation"]))
-            elif "CoordLocation" in stop:
-                stops.append(Stop(stop["CoordLocation"]))
+        if "stopLocationOrCoordLocation" in stops_raw:
+            for stop in stops_raw["stopLocationOrCoordLocation"]:
+                if "StopLocation" in stop:
+                    stops.append(Stop(stop["StopLocation"]))
+                elif "CoordLocation" in stop:
+                    stops.append(Stop(stop["CoordLocation"]))
 
         return stops
 
@@ -693,8 +700,9 @@ class Client():
 
         find_exception(trips_raw)
 
-        for trip in trips_raw["Trip"]:
-            trips.append(Trip(trip))
+        if "Trip" in trips_raw:
+            for trip in trips_raw["Trip"]:
+                trips.append(Trip(trip))
 
         return trips
 
@@ -766,7 +774,8 @@ class Client():
 
         find_exception(trips_raw)
 
-        for trip in trips_raw["Trip"]:
-            trips.append(Trip(trip))
+        if "Trip" in trips_raw:
+            for trip in trips_raw["Trip"]:
+                trips.append(Trip(trip))
 
         return trips
\ No newline at end of file
