@@ -12,15 +12,15 @@ except ImportError:
 def journey_detail(accessId: str,
         id: str,
         json: bool = True,
-        date: Union[str, datetime] = None, # type: ignore
+        date: Union[str, datetime, None] = None,
         poly: bool = False,
         polyEnc: Literal["DLT", "GPA", "N"] = "N",
         showPassingPoints: bool = False,
-        rtMode: Literal["FULL", "INFOS", "OFF", "REALTIME", "SERVER_DEFAULT"] = None, # type: ignore
-        fromId: str = None, # type: ignore
-        fromIdx: str = None, # type: ignore
-        toId: str = None, # type: ignore
-        toIdx: str = None, # type: ignore
+        rtMode: Union[Literal["FULL", "INFOS", "OFF", "REALTIME", "SERVER_DEFAULT"], None] = None,
+        fromId: Union[str, None] = None,
+        fromIdx: Union[int, None] = None,
+        toId: Union[str, None] = None,
+        toIdx: Union[int, None] = None,
         baim: bool = False
     ) -> dict:
     """The journey_detail method will deliver information about the complete route of a vehicle. The journey
@@ -66,10 +66,6 @@ def journey_detail(accessId: str,
 
     output = get("https://www.rmv.de/hapi/journeyDetail", params=payload, headers=headers)
 
-    # Exceptions checker moved to normal methods
-    # and exceptions will no longer raise in raw ones.
-    # find_exception(output.json())
-
     if json:
         return output.json()
     else:
