@@ -14,31 +14,31 @@ def trip_recon(accessId: str,
         json: bool = True,
         poly: bool = False,
         polyEnc: Literal["DLT", "GPA", "N"] = "N",
-        date: Union[str, datetime] = None, # type: ignore
-        useCombinedComparison: bool = None, # type: ignore
-        acceptGaps: bool = None, # type: ignore
-        allowDummySections: bool = None, # type: ignore
-        flagAllNonReachable: bool = None, # type: ignore
-        matchCatStrict: bool = None, # type: ignore
-        matchIdNonBlank: bool = None, # type: ignore
-        matchIdStrict: bool = None, # type: ignore
-        matchNumStrict: bool = None, # type: ignore
-        matchRtType: bool = None, # type: ignore
-        enableRtFullSearch: bool = None, # type: ignore
-        enableReplacements: bool = None, # type: ignore
-        arrL: int = None, # type: ignore
-        arrU: int = None, # type: ignore
-        depL: int = None, # type: ignore
-        depU: int = None, # type: ignore
+        date: Union[str, datetime, None] = None,
+        useCombinedComparison: Union[bool, None] = None,
+        acceptGaps: Union[bool, None] = None,
+        allowDummySections: Union[bool, None] = None,
+        flagAllNonReachable: Union[bool, None] = None,
+        matchCatStrict: Union[bool, None] = None,
+        matchIdNonBlank: Union[bool, None] = None,
+        matchIdStrict: Union[bool, None] = None,
+        matchNumStrict: Union[bool, None] = None,
+        matchRtType: Union[bool, None] = None,
+        enableRtFullSearch: Union[bool, None] = None,
+        enableReplacements: Union[bool, None] = None,
+        arrL: Union[int, None] = None,
+        arrU: Union[int, None] = None,
+        depL: Union[int, None] = None,
+        depU: Union[int, None] = None,
         passlist: bool = False,
         showPassingPoints: bool = False,
-        rtMode: Literal["FULL", "INFOS", "OFF", "REALTIME", "SERVER_DEFAULT"] = None, # type: ignore
+        rtMode: Union[Literal["FULL", "INFOS", "OFF", "REALTIME", "SERVER_DEFAULT"], None] = None,
         eco: bool = False,
         ecoCmp: bool = False,
-        ecoParams: str = None, # type: ignore
-        tariff: bool = None, # type: ignore
-        trafficMessages: bool = None, # type: ignore
-        travellerProfileData: str = None # type: ignore
+        ecoParams: Union[str, None] = None,
+        tariff: Union[bool, None] = None,
+        trafficMessages: Union[bool, None] = None,
+        travellerProfileData: Union[str, None] = None
     ) -> dict:
     """Reconstructing a trip can be achieved using the reconstruction context provided by any trip result in the
     ctxRecon attribute of Trip element. The result will be a true copy of the original trip search result given
@@ -102,10 +102,6 @@ def trip_recon(accessId: str,
 
     output = get("https://www.rmv.de/hapi/recon", params=payload, headers=headers)
 
-    # Exceptions checker moved to normal methods
-    # and exceptions will no longer raise in raw ones.
-    # find_exception(output.json())
-
     if json:
         return output.json()
     else:
